<?php 
function _load($userId)
{
	// See https://developers.google.com/youtube/2.0/reference
	// If prettyprint=true, the results returned by the server will be human readable
	$sxml = simplexml_load_file('http://gdata.youtube.com/feeds/api/users/' . $userId . '/playlists?max-results=50');

	// If userId is not a valid username
	if(!$sxml) {
		return trim(libxml_get_last_error()->message);
	}

	// Use that namespace. Don't have the URL hard-coded
	$ns = $sxml->getNamespaces(true);
	$totalResults = $sxml->children($ns['openSearch'])->totalResults;  
		
	// If no playlists found
	if ($totalResults == 0) {
		return 'totalResults: ' . $totalResults;
	}
		
	// Get a prefixed unique identifier based on the current time in microseconds for player iframe and playlist div
	$ifname = uniqid('player_', false);
	$divid = uniqid('playlist_', false);
		
	// Player
	$html = '<div class="player-container">';
	$html .= '<iframe name="' . $ifname . '" type="text/html" width="960" height="720" frameborder="0"';
	$html .= ' src="http://www.youtube.com/embed/videoseries?list=' . $sxml->entry->children($ns['yt'])->playlistId;
	$html .= '&showinfo=1" allowfullscreen></iframe></div>';
		
	// Playlist
	$html .= '<div id="' . $divid . '" class="playlists-container"><ul class="videos">';
	foreach ($sxml->entry as $entry) {
		$countHint = $entry->children($ns['gd'])->feedLink->attributes()->countHint;
		// No empty playlists
		if($countHint > 0) {
			$title = $entry->title;
			$playlistId = $entry->children($ns['yt'])->playlistId;
			$thumbnail = $entry->children($ns['media'])->group->thumbnail[0]->attributes()->url;
			$html .= '<li><a href="http://www.youtube.com/embed/videoseries?list=' . $playlistId . '&showinfo=1"';
			$html .= ' target="' . $ifname . '" title="' . $title . '(' . $countHint . ' videos)">';
			$html .= '<img src="' . $thumbnail . '" alt="' . $title . '" />';
			$html .= '<span class="pl_title">' . $title . '</span>';
			$html .= '<span class="pl_countHint">' . $countHint . ' videos</span></a></li>';
		}
	}

	// JavaScript for playlist scrolling on touch devices
	$html .= '</ul></div><script type="text/javascript">touchScroll("' . $divid . '");</script>';
	return $html;
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<title>YouTube User Playlists</title>
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="stylesheet" href="../css/ytuserplaylists.css" type="text/css" />
<script src="../js/touchScroll.js" type="text/javascript"></script>
</head>
<body>
<?php
echo _load('YouTube');
?>
</body>
</html> 